#ifndef __COMMON_H__
#define __COMMON_H__

#include <stdlib.h>
#include <unistd.h>

typedef enum
{
    OP_NULL                = 0,
    OP_FILE_OPEN           = 1,
    OP_FILE_OPEN_MULTIPLE  = 2,
    OP_FILE_SAVE           = 3,
    OP_FOLDER              = 4
} Operation;

#define SOCK_DIR  "ksocket-"
#define SOCK_NAME "kdialogd"

const char * getSockName(int display)
{
    char *user=getenv("USER"),
         *sock=NULL;

    if(!user)
        user=getenv("LOGNAME");

    if(user)
    {
        char *tmp=getenv("KDETMP");

        if(!tmp || !tmp[0])
            tmp=getenv("TMPDIR");

        if(!tmp || !tmp[0])
            tmp="/tmp";

        sock=(char *)malloc(strlen(tmp)+strlen(user)+32+strlen(SOCK_DIR)+strlen(SOCK_NAME));
        sprintf(sock, "%s/%s%s/%s-%d", tmp, SOCK_DIR, user, SOCK_NAME, display);
    }

    return sock;
}

static int readBlock(int fd, char* pData, int size)
{
    int bytesToRead=size;

    do
    {
        fd_set fdSet;

        FD_ZERO(&fdSet);
        FD_SET(fd, &fdSet);

        if(select(fd + 1, &fdSet, NULL, NULL, NULL)<0)
            return 0;

        if(FD_ISSET(fd, &fdSet))
        {
            int bytesRead=read(fd, &pData[size-bytesToRead], bytesToRead);

            if (bytesRead>0)
                bytesToRead-=bytesRead;
            else
                return 0;
        }
    }
    while(bytesToRead>0);

    return 1;
}

static int writeBlock(int fd, const char *pData, int size)
{
    int bytesToWrite=size;

    do
    {
        fd_set fdSet;

        FD_ZERO(&fdSet);
        FD_SET(fd, &fdSet);

        if(select(fd + 1, NULL, &fdSet, NULL, NULL)<0)
            return 0;

        if(FD_ISSET(fd, &fdSet))
        {
            int bytesWritten=write(fd, (char *)&pData[size-bytesToWrite], bytesToWrite);

            if (bytesWritten>0)
                bytesToWrite-=bytesWritten;
            else
                return 0;
        }
    }
    while(bytesToWrite>0);

    return 1;
}

#endif
